@@ -4,7 +4,7 @@ from itertools import product
 
 import cognite.airworkflow.constants as const
 from cognite.airworkflow.function_deployer import FunctionDeployer
-from cognite.airworkflow.master_config import get_deployments, get_master_config
+from cognite.airworkflow.master_config import get_master_config, get_parallel_deployment
 from cognite.airworkflow.model.schedule_assets import execute
 from cognite.airworkflow.model_asset_hierarchy import ModelAssetHierarchy
 from cognite.airworkflow.util import cdf, env, functions, github
@@ -12,9 +12,16 @@ from cognite.airworkflow.util import cdf, env, functions, github
 
 def handle_asset_hierarchy():
     _, project_to_config = get_master_config()
+    assert len(sys.argv) < 3, "Expected not more than two arguments"
+
+    if len(sys.argv) == 2:
+        airInfra = sys.argv[2] == "True"
+    else:
+        airInfra = False
+
     for project, config in project_to_config.items():
         print(f"Running Model Asset Hierarchy create/update for project {project}")
-        ModelAssetHierarchy(config, project).create_or_update()
+        ModelAssetHierarchy(config, project, airInfra).create_or_update()
 
 
 def handle_function_deployments():
@@ -22,14 +29,13 @@ def handle_function_deployments():
     github_ref = env.get_env_value("GITHUB_REF")
     is_delete = "IS_DELETE" in os.environ and os.environ["IS_DELETE"] == "true"
     is_pr = github_event_name == "pull_request"
-
     assert (
         len(sys.argv) >= 3 and sys.argv[2]
     ), "Expected a function name passed as a command line argument, but got nothing"
-    function_name = sys.argv[2].split("/")[-1] if "/" in sys.argv[2] else sys.argv[2]
+    # function_name = sys.argv[2].split("/")[-1] if "/" in sys.argv[2] else sys.argv[2]
+    function_name, project_name = sys.argv[2].split("@")
     print(f"HANDLING {github_event_name} ON {github_ref} FOR FUNCTION {function_name}")
-
-    for deployment in get_deployments(function_name):
+    for deployment in get_parallel_deployment(function_name, project_name):
         FunctionDeployer(deployment, is_delete, is_pr).handle_deployment()
 
 
@@ -74,6 +80,7 @@ def handle_check_deployment():
     client = cdf.experimental_client(project_name)
     model_asset = client.assets.retrieve(external_id=function_name)
     if model_asset is None:
+        print(str(True))
         return str(True)
     cdf_model_version = model_asset.metadata["modelVersion"]
     configuration = get_master_config()[1][project_name]
@@ -86,6 +93,7 @@ def handle_check_deployment():
 
 
 if __name__ == "__main__":
+    assert len(sys.argv) > 0, "Expected at least one argument."
 
     if sys.argv[1] == "model":
         handle_asset_hierarchy()
